@@ -157,7 +157,7 @@ arma::vec locLinSmootherC (double bw, int n, arma::vec x, arma::vec y, bool db_k
     }
     den = (s2*s0 - s1*s1);
 
-    if(abs(den)> TOLERANCE)
+    if(fabs(den)> TOLERANCE)
     {
       beta0[i] = (s2*t0 - s1*t1)/den;
     }
@@ -864,11 +864,11 @@ arma::cube DiffA(arma::vec y, arma::mat X, int m, double tau_n = 0, int ind = 2)
 //' @name Heter_LRV
 //' @title Long-run covariance matrix estimators
 //' @description \loadmathjax The function provides a wide range of estimators for the long-run covariance matrix estimation in non-stationary time series with covariates.
-//' @param e, vector, if the plug-in estimator is used, e should be the vector of residuals, OLS or nonparametric ones. If the difference-based debiased method is adopted, e should be the response time series, i.e., \mjseqn{y}. Specially, e should also be the response time series, i.e., \mjseqn{y}, if the plug-in estimator using the \mjseqn{\breve{\beta}}, the pilot estimator proposed in Bai and Wu (2023).
+//' @param e, vector, if the plug-in estimator is used, e should be the vector of residuals, OLS or nonparametric ones. If the difference-based debiased method is adopted, e should be the response time series, i.e., \mjseqn{y}. Specially, e should also be the response time series, i.e., \mjseqn{y}, if the plug-in estimator using the \mjseqn{\breve{\beta}}, the pilot estimator proposed in Bai and Wu (2024).
 //' @param X, a matrix \mjseqn{n\times p}
 //' @param m, integer, the window size.
 //' @param tau_n, double, the smoothing parameter in the estimator. If tau_n is 0, a rule-of-thumb value will be automatically used.
-//' @param lrv_method, the method of long-run variance estimation, lrvmethod = 0 uses the plug-in estimator in Zhou (2010), lrvmethod = 1 offers the debias difference-based estimator in Bai and Wu (2023), lrvmethod = 2 provides the plug-in estimator using the \mjseqn{\breve{\beta}}, the pilot estimator proposed in Bai and Wu (2023)
+//' @param lrv_method, the method of long-run variance estimation, lrvmethod = 0 uses the plug-in estimator in Zhou (2010), lrvmethod = 1 offers the debias difference-based estimator in Bai and Wu (2024), lrvmethod = 2 provides the plug-in estimator using the \mjseqn{\breve{\beta}}, the pilot estimator proposed in Bai and Wu (2024)
 //' @param ind,  types of kernels
 //' @param ncp,  1 no change points, 0 possible change points
 //'* 1 Triangular \mjseqn{1-|u|}, \mjseqn{u \le 1}
@@ -887,7 +887,7 @@ arma::cube DiffA(arma::vec y, arma::mat X, int m, double tau_n = 0, int ind = 2)
 //' data = Qct_reg(1000, param)
 //' sigma = Heter_LRV(data$y, data$x, 3, 0.3, lrv_method = 1)
 //' @references
-//' Bai, L., & Wu, W. (2023). Difference-based covariance matrix estimate in time series nonparametric regression with applications to specification tests.
+//' Bai, L., & Wu, W. (2024). Difference-based covariance matrix estimation in time series nonparametric regression with application to specification tests. Biometrika, asae013.
 //'
 //' Zhou, Z. and Wu, W. B. (2010). Simultaneous inference of linear models with time varying coefficients.J. R. Stat. Soc. Ser. B. Stat. Methodol., 72(4):513–531.
 // [[Rcpp::export]]
@@ -1190,9 +1190,9 @@ arma::vec sim_Phi_heter_KS(List data,
     tmp = sigma.slice(r)(0,0) * R.slice(r).row(0);//1*B
     s2 = s2 + tmp.t() - K_bias.t(); ;//B*1
     if(r == m){
-      maxs = abs(s2);
+      maxs = arma::abs(s2);
     }else{
-      maxs = (abs(s2) > maxs)%abs(s2) + (abs(s2) <= maxs)%maxs;
+      maxs = (arma::abs(s2) > maxs)%arma::abs(s2) + (arma::abs(s2) <= maxs)%maxs;
     }
   }
   KS_dist = maxs ;
@@ -1369,7 +1369,7 @@ double gcv_cov (double bw,
 //' Rc = array(rnorm(n*p*B_c),dim = c(p,B_c,n))
 //' result1 = LocLinear(0.2, t, data$y, data$x)
 //' critical <- MV_critical(data$y, result1, Rc, c(3,4,5), c(0.2, 0.25, 0.3))
-//' @references #' Bai, L., and Wu, W. (2023). Detecting long-range dependence for time-varying linear models. To appear in Bernoulli
+//' @references Bai, L., & Wu, W. (2024). Difference-based covariance matrix estimation in time series nonparametric regression with application to specification tests. Biometrika, asae013.
 // [[Rcpp::export]]
 arma::mat MV_critical(arma::vec y, List data, arma::cube R,
                       arma::vec gridm,
@@ -1453,7 +1453,7 @@ arma::mat MV_critical(arma::vec y, List data, arma::cube R,
 //' mv_result = MV_ise_heter_critical(critical,  1)
 //' m = gridm[mv_result$minp + 1]
 //' tau_n = gridtau[mv_result$minq + 1]
-//' @references  Bai, L., and Wu, W. (2023). Detecting long-range dependence for time-varying linear models. To appear in Bernoulli
+//' @references  Bai, L., & Wu, W. (2024). Difference-based covariance matrix estimation in time series nonparametric regression with application to specification tests. Biometrika, asae013.
 // [[Rcpp::export]]
 List MV_ise_heter_critical(arma::mat critical, int neighbour)
 {
@@ -1464,6 +1464,7 @@ List MV_ise_heter_critical(arma::mat critical, int neighbour)
   int pl,pu,ql,qu;
   int minp, minq;
   double min_ise = R_PosInf;
+  minp = minq = 0;
 
   for(int p = neighbour; p < M - neighbour; p++){
     for(int q = 0; q < Tau; q++){
@@ -1539,6 +1540,7 @@ List MV_ise_heter(arma::cube lrv_cub, int dim, int n,int neighbour)
   double s, tmp, tmps;
   int pl,pu,ql,qu;
   int minp, minq;
+  minp = minq = 0;
   double min_ise = R_PosInf;
 
   for(int p = neighbour; p < M - neighbour; p++){
@@ -1743,7 +1745,7 @@ arma::cube MV_cov_heter(arma::vec e, arma::mat X,
 //' t = (1:n)/n
 //' data = bregress2(n, 2, 1) # time series regression model with 2 changes points
 //' critical = MV_critical_cp(data$y, data$x,t,  c(3,4,5), c(0.2,0.25, 0.3))
-//' @references  Bai, L., and Wu, W. (2023). Detecting long-range dependence for time-varying linear models. To appear in Bernoulli
+//' @references  Bai, L., & Wu, W. (2024). Difference-based covariance matrix estimation in time series nonparametric regression with application to specification tests. Biometrika, asae013.
 // [[Rcpp::export]]
  arma::mat MV_critical_cp(arma::vec y, arma::mat X, arma::vec t,
                           arma::vec gridm,
